# Process Introduction
![](/uploads/uh9RoLA3/images/m_82b445c5e9505accb89e9242e1c35374_r.png)

# Docking Instructions
## Interface Request Address:
Test Environment Address: http://120.25.245.20:8092/OpenApi
Production Environment Address (Mainland China): https://cloud.assetscontrols.com:3443/OpenApi
Production Environment Address (Hong Kong, China): https://icloud.assetscontrols.com:3443/OpenApi
Production Environment Address (Cairo): https://kcloud.assetscontrols.com:3443/OpenApi

## Request Method:
`POST`

## Request Header:
| Parameter Name | Required | Type | Description |
| ---- | ---- | ---- | ---- |
| Content-Type | Yes | string | Request type: application/json |

## 1.Obtain Token Information
The token obtained by the same user is a fixed value. It is recommended to cache the token and there is no need to request it repeatedly.

### Request Path: /login
Test Environment Address: http://120.25.245.20:8092/OpenApi/login
Production Environment Address (Mainland China): https://cloud.assetscontrols.com:3443/OpenApi/login
Production Environment Address (Hong Kong, China): https://icloud.assetscontrols.com:3443/OpenApi/login
Production Environment Address (Cairo): https://kcloud.assetscontrols.com:3443/OpenApi/login

### Request Parameters:

| Parameter Name | Required | Type | Description |
| ---- | ---- | ---- | ---- |
| FUserName | Yes | string | User name |
| FPassword | Yes | string | Password (MD5(32)) |

### Return Example:
When correct, the return is:
```json
{
    "Result": 200,
    "Message":"success",
    "FObject": [{
        "FUserName": "admin",
        "FUserGUID": "63C399BD-2A0B-40E9-857D-6DEBF4908F92",
        "FTokenID": "DB7F20D9-84C3-44C3-B05A-06A9C392A189",
        "FExpireTime": "2020-07-30T08:00:00"
    }]
}
```

When incorrect, the return is:

```json
{
    "Result": 103,
    "Message": "userName or password is error",
    "FObject": null
}
```

### Explanation of Returned Parameters:

| Parameter Name | Type | Description |
| ---- | ---- | ---- |
| FUserName | String | User name |
| FUserGUID | String | Unique user identifier |
| FTokenID | String | Unique identity identifier (this is required for identity verification in all subsequent interface requests) |
| FExpireTime | DateTime | Account expiration time (UTC time. Add 8 hours to convert it to Beijing time) |

### Remarks:

More return error codes are as follows:
106: Account expired
103: Incorrect user name or password
102: Incorrect request parameters

### Postman Request Example: 
![](/uploads/uh9RoLA3/images/m_d6be02e2af31094005ef025207ebe574_r.png)

## 2.Concatenate the URL
Concatenate the URL according to the access environment
Access Environment Address:
Test Environment Address: http://120.25.245.20:8081/
Production Environment Address (Mainland China): https://cloud.assetscontrols.com:2443/
Production Environment Address (Hong Kong, China): https://icloud.assetscontrols.com:2443/
Production Environment Address (Cairo): https://kcloud.assetscontrols.com:2443/ 

### javascript example
```javascript
// Authentication information obtained from the above interface
const authInfo = FObject[0];

// Specify the system language as English
authInfo.FLanguage = 'en';

// Concatenate the address
// isIframe=1 is a fixed parameter, indicating that the current link is for embedding.
// iframeRouteCode=11 means the embedded page is real - time monitoring, and iframeRouteCode=12 means the embedded page is trajectory playback.
// params is the encoded authentication information
const jtCloudUrl = `https://xxx.assetscontrols.com:2443/?isIframe=1&iframeRouteCode=11&params=${encodeURIComponent(JSON.stringify(authInfo))}`;
```

## 3.Embed the URL into a third-party system for presentation.
You just need to assign the obtained URL to the `src` attribute of the `iframe` tag in the system to be embedded.

`iframeRouteCode=11` corresponds to real-time monitoring.
http://120.25.245.20:8081/?isIframe=1&iframeRouteCode=11&params=%7B%22FUserName%22%3A%22jtrj%22%2C%22FUserGUID%22%3A%2275c43ea6-017a-4102-a83e-8f6329946b40%22%2C%22FTokenID%22%3A%22ec51d691-d9a7-4f74-95a8-1856be2ae745%22%2C%22FExpireTime%22%3A%222033-08-31T00%3A00%3A00%22%7D

![](/uploads/uh9RoLA3/images/m_d227179e449923cfc34af99ddd38b8ea_r.png)

`iframeRouteCode=12` corresponds to trajectory playback.
http://120.25.245.20:8081/?isIframe=1&iframeRouteCode=12&params=%7B%22FUserName%22%3A%22jtrj%22%2C%22FUserGUID%22%3A%2275c43ea6-017a-4102-a83e-8f6329946b40%22%2C%22FTokenID%22%3A%22ec51d691-d9a7-4f74-95a8-1856be2ae745%22%2C%22FExpireTime%22%3A%222033-08-31T00%3A00%3A00%22%7D

![](/uploads/uh9RoLA3/images/m_26598a09e85013e6201e2f8b9dcfc176_r.png)